This is a function that will pull a specified PPM extract from the Oliver API
for authorized users. The extract_name parameter must be either
fss_raw.csv, fss_extract.csv, notes_extract.csv, or grassroots_diff.csv.
1 | get_csv_extract(extract_name = NA)
|
extract_name |
A valid extract name available to the specified user. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.